KNOWN_UNITS_EXT = [
    ".automount",
    ".conf",
    ".link",
    ".mount",
    ".network",
    ".netdev",
    ".path",
    ".service",
    ".slice",
    ".socket",
    ".swap",
    ".target",
    ".timer"
]
KNOWN_UNITS_MUST_HAVE_UNITSECTION = [
    ".mount",
    ".service",
    ".socket",
    ".target"
]
KNOWN_RUNTIME_UNITS = [
    ".slice"
]